@@ -1,7 +1,7 @@
 #!/usr/bin/env python
 
 """
-Copyright (c) 2006-2016 sqlmap developers (http://sqlmap.org/)
+Copyright (c) 2006-2017 sqlmap developers (http://sqlmap.org/)
 See the file 'doc/COPYING' for copying permission
 """
 
@@ -51,7 +51,7 @@ class Custom:
 
                 return output
             elif not isStackingAvailable() and not conf.direct:
-                    warnMsg = "execution of custom SQL queries is only "
+                    warnMsg = "execution of non-query SQL statements is only "
                     warnMsg += "available when stacked queries are supported"
                     logger.warn(warnMsg)
 
@@ -119,13 +119,13 @@ class Custom:
         infoMsg = "executing SQL statements from given file(s)"
         logger.info(infoMsg)
 
-        for sfile in re.split(PARAMETER_SPLITTING_REGEX, conf.sqlFile):
-            sfile = sfile.strip()
+        for filename in re.split(PARAMETER_SPLITTING_REGEX, conf.sqlFile):
+            filename = filename.strip()
 
-            if not sfile:
+            if not filename:
                 continue
 
-            snippet = getSQLSnippet(Backend.getDbms(), sfile)
+            snippet = getSQLSnippet(Backend.getDbms(), filename)
 
             if snippet and all(query.strip().upper().startswith("SELECT") for query in filter(None, snippet.split(';' if ';' in snippet else '\n'))):
                 for query in filter(None, snippet.split(';' if ';' in snippet else '\n')):
