@@ -79,7 +79,7 @@ class Entries:
             if Backend.getIdentifiedDbms() in (DBMS.ORACLE, DBMS.DB2, DBMS.HSQLDB):
                 conf.tbl = conf.tbl.upper()
 
-            tblList = conf.tbl.split(",")
+            tblList = conf.tbl.split(',')
         else:
             self.getTables()
 
@@ -192,7 +192,14 @@ class Entries:
                     query = agent.whereQuery(query)
 
                     if not entries and query:
-                        entries = inject.getValue(query, blind=False, time=False, dump=True)
+                        try:
+                            entries = inject.getValue(query, blind=False, time=False, dump=True)
+                        except KeyboardInterrupt:
+                            entries = None
+                            kb.dumpKeyboardInterrupt = True
+                            clearConsoleLine()
+                            warnMsg = "Ctrl+C detected in dumping phase"
+                            logger.warn(warnMsg)
 
                     if not isNoneValue(entries):
                         if isinstance(entries, basestring):
@@ -415,9 +422,8 @@ class Entries:
 
     def dumpFoundColumn(self, dbs, foundCols, colConsider):
         message = "do you want to dump entries? [Y/n] "
-        output = readInput(message, default="Y")
 
-        if output and output[0] not in ("y", "Y"):
+        if not readInput(message, default='Y', boolean=True):
             return
 
         dumpFromDbs = []
@@ -428,14 +434,14 @@ class Entries:
                 message += "[%s]\n" % unsafeSQLIdentificatorNaming(db)
 
         message += "[q]uit"
-        test = readInput(message, default="a")
+        choice = readInput(message, default='a')
 
-        if not test or test in ("a", "A"):
+        if not choice or choice in ('a', 'A'):
             dumpFromDbs = dbs.keys()
-        elif test in ("q", "Q"):
+        elif choice in ('q', 'Q'):
             return
         else:
-            dumpFromDbs = test.replace(" ", "").split(",")
+            dumpFromDbs = choice.replace(" ", "").split(',')
 
         for db, tblData in dbs.items():
             if db not in dumpFromDbs or not tblData:
@@ -451,16 +457,16 @@ class Entries:
 
             message += "[s]kip\n"
             message += "[q]uit"
-            test = readInput(message, default="a")
+            choice = readInput(message, default='a')
 
-            if not test or test in ("a", "A"):
+            if not choice or choice in ('a', 'A'):
                 dumpFromTbls = tblData
-            elif test in ("s", "S"):
+            elif choice in ('s', 'S'):
                 continue
-            elif test in ("q", "Q"):
+            elif choice in ('q', 'Q'):
                 return
             else:
-                dumpFromTbls = test.replace(" ", "").split(",")
+                dumpFromTbls = choice.replace(" ", "").split(',')
 
             for table, columns in tblData.items():
                 if table not in dumpFromTbls:
@@ -472,7 +478,7 @@ class Entries:
                 if conf.excludeCol:
                     colList = [_ for _ in colList if _ not in conf.excludeCol.split(',')]
 
-                conf.col = ",".join(colList)
+                conf.col = ','.join(colList)
                 kb.data.cachedColumns = {}
                 kb.data.dumpedTable = {}
 
@@ -483,9 +489,8 @@ class Entries:
 
     def dumpFoundTables(self, tables):
         message = "do you want to dump tables' entries? [Y/n] "
-        output = readInput(message, default="Y")
 
-        if output and output[0].lower() != "y":
+        if not readInput(message, default='Y', boolean=True):
             return
 
         dumpFromDbs = []
@@ -496,14 +501,14 @@ class Entries:
                 message += "[%s]\n" % unsafeSQLIdentificatorNaming(db)
 
         message += "[q]uit"
-        test = readInput(message, default="a")
+        choice = readInput(message, default='a')
 
-        if not test or test.lower() == "a":
+        if not choice or choice.lower() == 'a':
             dumpFromDbs = tables.keys()
-        elif test.lower() == "q":
+        elif choice.lower() == 'q':
             return
         else:
-            dumpFromDbs = test.replace(" ", "").split(",")
+            dumpFromDbs = choice.replace(" ", "").split(',')
 
         for db, tablesList in tables.items():
             if db not in dumpFromDbs or not tablesList:
@@ -519,16 +524,16 @@ class Entries:
 
             message += "[s]kip\n"
             message += "[q]uit"
-            test = readInput(message, default="a")
+            choice = readInput(message, default='a')
 
-            if not test or test.lower() == "a":
+            if not choice or choice.lower() == 'a':
                 dumpFromTbls = tablesList
-            elif test.lower() == "s":
+            elif choice.lower() == 's':
                 continue
-            elif test.lower() == "q":
+            elif choice.lower() == 'q':
                 return
             else:
-                dumpFromTbls = test.replace(" ", "").split(",")
+                dumpFromTbls = choice.replace(" ", "").split(',')
 
             for table in dumpFromTbls:
                 conf.tbl = table
