@@ -1,7 +1,7 @@
 #!/usr/bin/env python
 
 """
-Copyright (c) 2006-2016 sqlmap developers (http://sqlmap.org/)
+Copyright (c) 2006-2017 sqlmap developers (http://sqlmap.org/)
 See the file 'doc/COPYING' for copying permission
 """
 
@@ -33,8 +33,8 @@ from lib.core.exception import SqlmapUserQuitException
 from lib.core.settings import CURRENT_DB
 from lib.core.settings import METADB_SUFFIX
 from lib.request import inject
-from lib.techniques.brute.use import columnExists
-from lib.techniques.brute.use import tableExists
+from lib.utils.brute import columnExists
+from lib.utils.brute import tableExists
 
 class Search:
     """
@@ -47,7 +47,7 @@ class Search:
     def searchDb(self):
         foundDbs = []
         rootQuery = queries[Backend.getIdentifiedDbms()].search_db
-        dbList = conf.db.split(",")
+        dbList = conf.db.split(',')
 
         if Backend.isDbms(DBMS.MYSQL) and not kb.data.has_information_schema:
             dbCond = rootQuery.inband.condition2
@@ -146,18 +146,18 @@ class Search:
 
         if bruteForce:
             message = "do you want to use common table existence check? %s" % ("[Y/n/q]" if Backend.getIdentifiedDbms() in (DBMS.ACCESS,) else "[y/N/q]")
-            test = readInput(message, default="Y" if "Y" in message else "N")
+            choice = readInput(message, default='Y' if 'Y' in message else 'N').upper()
 
-            if test[0] in ("n", "N"):
+            if choice == 'N':
                 return
-            elif test[0] in ("q", "Q"):
+            elif choice == 'Q':
                 raise SqlmapUserQuitException
             else:
-                regex = "|".join(conf.tbl.split(","))
+                regex = '|'.join(conf.tbl.split(','))
                 return tableExists(paths.COMMON_TABLES, regex)
 
         foundTbls = {}
-        tblList = conf.tbl.split(",")
+        tblList = conf.tbl.split(',')
         rootQuery = queries[Backend.getIdentifiedDbms()].search_table
         tblCond = rootQuery.inband.condition
         dbCond = rootQuery.inband.condition2
@@ -171,7 +171,7 @@ class Search:
                 tbl = tbl.upper()
 
             infoMsg = "searching table"
-            if tblConsider == "1":
+            if tblConsider == '1':
                 infoMsg += "s LIKE"
             infoMsg += " '%s'" % unsafeSQLIdentificatorNaming(tbl)
 
@@ -179,7 +179,7 @@ class Search:
                 conf.db = self.getCurrentDb()
 
             if dbCond and conf.db:
-                _ = conf.db.split(",")
+                _ = conf.db.split(',')
                 whereDbsQuery = " AND (" + " OR ".join("%s = '%s'" % (dbCond, unsafeSQLIdentificatorNaming(db)) for db in _) + ")"
                 infoMsg += " for database%s '%s'" % ("s" if len(_) > 1 else "", ", ".join(db for db in _))
             elif conf.excludeSysDbs:
@@ -264,7 +264,7 @@ class Search:
                         if tblConsider == "2":
                             continue
                     else:
-                        for db in conf.db.split(",") if conf.db else (self.getCurrentDb(),):
+                        for db in conf.db.split(',') if conf.db else (self.getCurrentDb(),):
                             db = safeSQLIdentificatorNaming(db)
                             if db not in foundTbls:
                                 foundTbls[db] = []
@@ -345,20 +345,19 @@ class Search:
 
         if bruteForce:
             message = "do you want to use common column existence check? %s" % ("[Y/n/q]" if Backend.getIdentifiedDbms() in (DBMS.ACCESS,) else "[y/N/q]")
-            test = readInput(message, default="Y" if "Y" in message else "N")
+            choice = readInput(message, default='Y' if 'Y' in message else 'N').upper()
 
-            if test[0] in ("n", "N"):
+            if choice == 'N':
                 return
-            elif test[0] in ("q", "Q"):
+            elif choice == 'Q':
                 raise SqlmapUserQuitException
             else:
                 regex = '|'.join(conf.col.split(','))
                 conf.dumper.dbTableColumns(columnExists(paths.COMMON_COLUMNS, regex))
 
                 message = "do you want to dump entries? [Y/n] "
-                output = readInput(message, default="Y")
 
-                if output and output[0] not in ("n", "N"):
+                if readInput(message, default='Y', boolean=True):
                     self.dumpAll()
 
                 return
@@ -370,7 +369,7 @@ class Search:
         whereTblsQuery = ""
         infoMsgTbl = ""
         infoMsgDb = ""
-        colList = conf.col.split(",")
+        colList = conf.col.split(',')
 
         if conf.excludeCol:
             colList = [_ for _ in colList if _ not in conf.excludeCol.split(',')]
@@ -399,7 +398,7 @@ class Search:
             foundCols[column] = {}
 
             if conf.tbl:
-                _ = conf.tbl.split(",")
+                _ = conf.tbl.split(',')
                 whereTblsQuery = " AND (" + " OR ".join("%s = '%s'" % (tblCond, unsafeSQLIdentificatorNaming(tbl)) for tbl in _) + ")"
                 infoMsgTbl = " for table%s '%s'" % ("s" if len(_) > 1 else "", ", ".join(unsafeSQLIdentificatorNaming(tbl) for tbl in _))
 
@@ -407,7 +406,7 @@ class Search:
                 conf.db = self.getCurrentDb()
 
             if conf.db:
-                _ = conf.db.split(",")
+                _ = conf.db.split(',')
                 whereDbsQuery = " AND (" + " OR ".join("%s = '%s'" % (dbCond, unsafeSQLIdentificatorNaming(db)) for db in _) + ")"
                 infoMsgDb = " in database%s '%s'" % ("s" if len(_) > 1 else "", ", ".join(unsafeSQLIdentificatorNaming(db) for db in _))
             elif conf.excludeSysDbs:
@@ -434,13 +433,13 @@ class Search:
                     # column(s) provided
                     values = []
 
-                    for db in conf.db.split(","):
-                        for tbl in conf.tbl.split(","):
+                    for db in conf.db.split(','):
+                        for tbl in conf.tbl.split(','):
                             values.append([safeSQLIdentificatorNaming(db), safeSQLIdentificatorNaming(tbl, True)])
 
                 for db, tbl in filterPairValues(values):
                     db = safeSQLIdentificatorNaming(db)
-                    tbls = tbl.split(",") if not isNoneValue(tbl) else []
+                    tbls = tbl.split(',') if not isNoneValue(tbl) else []
 
                     for tbl in tbls:
                         tbl = safeSQLIdentificatorNaming(tbl, True)
@@ -507,7 +506,7 @@ class Search:
                         if db not in foundCols[column]:
                             foundCols[column][db] = []
                 else:
-                    for db in conf.db.split(",") if conf.db else (self.getCurrentDb(),):
+                    for db in conf.db.split(',') if conf.db else (self.getCurrentDb(),):
                         db = safeSQLIdentificatorNaming(db)
                         if db not in foundCols[column]:
                             foundCols[column][db] = []
