@@ -10,7 +10,7 @@ import re
 from lib.core.enums import HTTP_HEADER
 from lib.core.settings import WAF_ATTACK_VECTORS
 
-__product__ = "FortiWeb Web Application Firewall (Fortinet Inc.)"
+__product__ = "FortiWeb Web Application Firewall (Fortinet)"
 
 def detect(get_page):
     retval = False
